- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGenerating → bool
-
Whether generation is currently in progress.
no setter
- isInitialized → bool
-
Whether the model is loaded and ready for generation.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clean(
) → void -
dispose(
) → void -
loadModel(
String localPath) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendPrompt(
String prompt, {List< LlamaImageContent> ? images}) → Stream<String> - Sends a prompt and returns a stream of tokens.
-
sendPromptComplete(
String prompt, {List< LlamaImageContent> ? images}) → Future<String> - Sends a prompt and waits for the complete response.
-
sendPromptStream(
String prompt, {List< LlamaImageContent> ? images}) → Stream<StreamingChunk> - Sends a prompt and returns a stream of StreamingChunk with live performance metrics. Recommended method for UI use.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited